<?php
/**
 * wpbase functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package wpbase
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
add_action('after_setup_theme', function () {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on wpbase, use a find and replace
	 * to change 'wpbase' to the name of your theme in all the template files.
	 */
	load_theme_textdomain('wpbase', get_template_directory() . '/languages');

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support('title-tag');

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(array(
		// 'menu-1' => esc_html__('Primary', 'wpbase'),
	));

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support('html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	));
});

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
add_action('after_setup_theme', function () {
	$GLOBALS['content_width'] = apply_filters('wpbase_content_width', 640);
}, 0);

/**
 * Enqueue scripts and styles.
 */
add_action('wp_enqueue_scripts', function () {
	wp_enqueue_style('wpbase-style', get_stylesheet_uri());

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
});

//Modifie la barre du haut du tinyMCE
add_filter('mce_buttons', function($buttons) {
	//remove
	$remove = array('blockquote', 'wp_more', 'spellchecker', 'dfw', 'wp_adv');
	$buttons = array_diff($buttons, $remove);

	array_unshift($buttons, 'styleselect');
	//add hr example
	// array_push($buttons, 'hr');
	return $buttons;
});

//Modifie la 2e barre du tinyMCE
add_filter('mce_buttons_2', function($buttons) {
	// $remove = array('strikethrough', 'hr', 'forecolor', 'pastetext', 'removeformat', 'charmap', 'outdent', 'indent', 'undo', 'redo', 'wp_help');
	$remove = array( 'strikethrough', 'hr', 'forecolor', 'charmap', 'outdent', 'indent', 'wp_help' );
	$buttons = array_diff($buttons, $remove);

	return $buttons;
});

// Ajoute les class filter au tinyMCE
add_filter('tiny_mce_before_init', function($init_array) {
	$style_formats = array(
		array(
			'title' => 'Bloc emphase',
			'block' => 'p',
			'classes' => 'texteblocemphase',
			'wrapper' => false,
		),
		array(
			'title' => 'Texte couleur',
			'inline' => 'span',
			'classes' => 'p-color',
			'wrapper' => true,
		),
	);
	$init_array['style_formats'] = json_encode($style_formats);
	$init_array['block_formats'] = 'Paragraph=p;Heading 3=h3;Heading 4=h4;Heading 5=h5';
	return $init_array;
});

// Ajoute le css au tinyMCE
add_action('init', function() {
	add_editor_style('css/custom-editor-style.css');
});
